@@ -63,6 +63,7 @@ struct _GthMediaViewerPagePrivate {
 	gboolean        block_next_jump;
 	GdkCursor      *cursor;
 	GdkCursor      *cursor_void;
+	gboolean        cursor_visible;
 };
 
 
@@ -136,7 +137,10 @@ video_area_realize_cb (GtkWidget *widget,
 
 	self->priv->cursor = gdk_cursor_new (GDK_LEFT_PTR);
 	self->priv->cursor_void = gth_cursor_get (gtk_widget_get_window (self->priv->area), GTH_CURSOR_VOID);
-	gdk_window_set_cursor (gtk_widget_get_window (self->priv->area), self->priv->cursor);
+	if (self->priv->cursor_visible)
+		gdk_window_set_cursor (gtk_widget_get_window (self->priv->area), self->priv->cursor);
+	else
+		gdk_window_set_cursor (gtk_widget_get_window (self->priv->area), self->priv->cursor_void);
 
 	self->priv->caption_layout = gtk_widget_create_pango_layout (widget, "");
 	pango_layout_set_alignment (self->priv->caption_layout, PANGO_ALIGN_CENTER);
@@ -733,10 +737,12 @@ remove_fullscreen_toolbar (GthMediaViewerPage *self)
 	if (self->priv->fullscreen_toolbar == NULL)
 		return;
 
-	g_object_ref (self->priv->mediabar);
-	gtk_container_remove (GTK_CONTAINER (self->priv->fullscreen_toolbar), self->priv->mediabar);
-	gtk_box_pack_start (GTK_BOX (self->priv->area_box), self->priv->mediabar, FALSE, FALSE, 0);
-	g_object_unref (self->priv->mediabar);
+	if (self->priv->mediabar->parent == self->priv->fullscreen_toolbar) {
+		g_object_ref (self->priv->mediabar);
+		gtk_container_remove (GTK_CONTAINER (self->priv->fullscreen_toolbar), self->priv->mediabar);
+		gtk_box_pack_start (GTK_BOX (self->priv->area_box), self->priv->mediabar, FALSE, FALSE, 0);
+		g_object_unref (self->priv->mediabar);
+	}
 
 	gth_browser_unregister_fullscreen_control (self->priv->browser, self->priv->fullscreen_toolbar);
 	gtk_widget_destroy (self->priv->fullscreen_toolbar);
@@ -1065,7 +1071,7 @@ gth_media_viewer_page_real_view (GthViewerPage *base,
 
 	/**/
 
-	gth_viewer_page_file_loaded (GTH_VIEWER_PAGE (self), TRUE);
+	gth_viewer_page_file_loaded (GTH_VIEWER_PAGE (self), self->priv->file_data, TRUE);
 	g_signal_handlers_block_by_func(GET_WIDGET ("adjustment_position"), position_value_changed_cb, self);
 	gtk_adjustment_set_value (GTK_ADJUSTMENT (GET_WIDGET ("adjustment_position")), 0.0);
 	g_signal_handlers_unblock_by_func(GET_WIDGET ("adjustment_position"), position_value_changed_cb, self);
@@ -1119,10 +1125,12 @@ gth_media_viewer_page_real_fullscreen (GthViewerPage *base,
 		gtk_container_set_border_width (GTK_CONTAINER (self->priv->fullscreen_toolbar), 0);
 	}
 
-	g_object_ref (self->priv->mediabar);
-	gtk_container_remove (GTK_CONTAINER (self->priv->area_box), self->priv->mediabar);
-	gtk_container_add (GTK_CONTAINER (self->priv->fullscreen_toolbar), self->priv->mediabar);
-	g_object_unref (self->priv->mediabar);
+	if (self->priv->mediabar->parent == self->priv->area_box) {
+		g_object_ref (self->priv->mediabar);
+		gtk_container_remove (GTK_CONTAINER (self->priv->area_box), self->priv->mediabar);
+		gtk_container_add (GTK_CONTAINER (self->priv->fullscreen_toolbar), self->priv->mediabar);
+		g_object_unref (self->priv->mediabar);
+	}
 
 	gtk_widget_realize (self->priv->mediabar);
 	gtk_window_set_gravity (GTK_WINDOW (self->priv->fullscreen_toolbar), GDK_GRAVITY_SOUTH_EAST);
@@ -1139,15 +1147,19 @@ gth_media_viewer_page_real_show_pointer (GthViewerPage *base,
 {
 	GthMediaViewerPage *self = (GthMediaViewerPage*) base;
 
+	self->priv->cursor_visible = show;
+
+	if (show && (self->priv->cursor != NULL))
+		gdk_window_set_cursor (gtk_widget_get_window (self->priv->area), self->priv->cursor);
+
+	if (! show && (self->priv->cursor_void != NULL))
+		gdk_window_set_cursor (gtk_widget_get_window (self->priv->area), self->priv->cursor_void);
+
 	if (self->priv->fullscreen_toolbar != NULL) {
-		if (show) {
+		if (show)
 			gtk_widget_show (self->priv->fullscreen_toolbar);
-			gdk_window_set_cursor (gtk_widget_get_window (self->priv->area), self->priv->cursor);
-		}
-		else {
+		else
 			gtk_widget_hide (self->priv->fullscreen_toolbar);
-			gdk_window_set_cursor (gtk_widget_get_window (self->priv->area), self->priv->cursor_void);
-		}
 	}
 }
 
@@ -1274,6 +1286,7 @@ gth_media_viewer_page_instance_init (GthMediaViewerPage *self)
 	self->priv->video_fps_n = 0;
 	self->priv->video_fps_d = 0;
 	self->priv->icon = NULL;
+	self->priv->cursor_visible = TRUE;
 }
 
 
