@@ -76,7 +76,7 @@
 /* Copy the first part of user declarations.  */
 
 /* Line 189 of yacc.c  */
-#line 1 "albumtheme.y"
+#line 1 "../../../extensions/webalbums/albumtheme.y"
 
 /*
  *  GThumb
@@ -170,7 +170,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 37 "albumtheme.y"
+#line 37 "../../../extensions/webalbums/albumtheme.y"
 
 	char         *text;
 	int           ivalue;
@@ -1496,7 +1496,7 @@ yyreduce:
         case 2:
 
 /* Line 1455 of yacc.c  */
-#line 77 "albumtheme.y"
+#line 77 "../../../extensions/webalbums/albumtheme.y"
     {
 			yy_parsed_doc = (yyvsp[(1) - (1)].list);
 			if (yy_parsed_doc == NULL)
@@ -1509,7 +1509,7 @@ yyreduce:
   case 3:
 
 /* Line 1455 of yacc.c  */
-#line 86 "albumtheme.y"
+#line 86 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), gth_tag_new_html ((yyvsp[(1) - (2)].text)));
 			g_free ((yyvsp[(1) - (2)].text));
@@ -1519,7 +1519,7 @@ yyreduce:
   case 4:
 
 /* Line 1455 of yacc.c  */
-#line 91 "albumtheme.y"
+#line 91 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].tag));
 		;}
@@ -1528,7 +1528,7 @@ yyreduce:
   case 5:
 
 /* Line 1455 of yacc.c  */
-#line 95 "albumtheme.y"
+#line 95 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].tag));
 		;}
@@ -1537,20 +1537,20 @@ yyreduce:
   case 6:
 
 /* Line 1455 of yacc.c  */
-#line 99 "albumtheme.y"
+#line 99 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthTag *tag;
 
 			gth_loop_add_document ((yyvsp[(1) - (4)].loop), (yyvsp[(2) - (4)].list));
 			tag = gth_tag_new_loop ((yyvsp[(1) - (4)].loop));
-			(yyval.list) = g_list_prepend ((yyvsp[(4) - (4)].list), (yyvsp[(1) - (4)].loop));
+			(yyval.list) = g_list_prepend ((yyvsp[(4) - (4)].list), tag);
 		;}
     break;
 
   case 7:
 
 /* Line 1455 of yacc.c  */
-#line 107 "albumtheme.y"
+#line 107 "../../../extensions/webalbums/albumtheme.y"
     {
 			GList  *cond_list;
 			GthTag *tag;
@@ -1568,7 +1568,7 @@ yyreduce:
   case 8:
 
 /* Line 1455 of yacc.c  */
-#line 120 "albumtheme.y"
+#line 120 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		;}
@@ -1577,7 +1577,7 @@ yyreduce:
   case 9:
 
 /* Line 1455 of yacc.c  */
-#line 124 "albumtheme.y"
+#line 124 "../../../extensions/webalbums/albumtheme.y"
     {
 			/*if ($2 != NULL)
 				gth_parsed_doc_free ($2);*/
@@ -1588,7 +1588,7 @@ yyreduce:
   case 10:
 
 /* Line 1455 of yacc.c  */
-#line 131 "albumtheme.y"
+#line 131 "../../../extensions/webalbums/albumtheme.y"
     {
 			if (g_str_equal ((yyvsp[(2) - (3)].text), "thumbnail_caption")) {
 				(yyval.loop) = gth_loop_new (GTH_TAG_FOR_EACH_THUMBNAIL_CAPTION);
@@ -1599,18 +1599,18 @@ yyreduce:
 			else {
 				yyerror ("Wrong iterator: '%s', expected 'thumbnail_caption' or 'image_caption'", (yyvsp[(2) - (3)].text));
 				YYERROR;
-			}			
+			}
 		;}
     break;
 
   case 11:
 
 /* Line 1455 of yacc.c  */
-#line 144 "albumtheme.y"
+#line 144 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.loop) = gth_range_loop_new ();
 			gth_range_loop_set_range (GTH_RANGE_LOOP ((yyval.loop)), (yyvsp[(2) - (7)].text), (yyvsp[(4) - (7)].expr), (yyvsp[(6) - (7)].expr));
-			
+
 			g_free ((yyvsp[(2) - (7)].text));
 			gth_expr_unref ((yyvsp[(4) - (7)].expr));
 			gth_expr_unref ((yyvsp[(6) - (7)].expr));
@@ -1620,7 +1620,7 @@ yyreduce:
   case 12:
 
 /* Line 1455 of yacc.c  */
-#line 154 "albumtheme.y"
+#line 154 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(2) - (3)].expr));
 		;}
@@ -1629,7 +1629,7 @@ yyreduce:
   case 13:
 
 /* Line 1455 of yacc.c  */
-#line 158 "albumtheme.y"
+#line 158 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(3) - (5)].expr));
 		;}
@@ -1638,7 +1638,7 @@ yyreduce:
   case 14:
 
 /* Line 1455 of yacc.c  */
-#line 163 "albumtheme.y"
+#line 163 "../../../extensions/webalbums/albumtheme.y"
     {
 			gth_condition_add_document ((yyvsp[(1) - (3)].cond), (yyvsp[(2) - (3)].list));
 			(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].cond));
@@ -1648,7 +1648,7 @@ yyreduce:
   case 15:
 
 /* Line 1455 of yacc.c  */
-#line 168 "albumtheme.y"
+#line 168 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		;}
@@ -1657,7 +1657,7 @@ yyreduce:
   case 16:
 
 /* Line 1455 of yacc.c  */
-#line 173 "albumtheme.y"
+#line 173 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(2) - (3)].expr));
 		;}
@@ -1666,7 +1666,7 @@ yyreduce:
   case 17:
 
 /* Line 1455 of yacc.c  */
-#line 177 "albumtheme.y"
+#line 177 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(3) - (5)].expr));
 		;}
@@ -1675,7 +1675,7 @@ yyreduce:
   case 18:
 
 /* Line 1455 of yacc.c  */
-#line 182 "albumtheme.y"
+#line 182 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr      *else_expr;
 			GthCondition *cond;
@@ -1692,7 +1692,7 @@ yyreduce:
   case 19:
 
 /* Line 1455 of yacc.c  */
-#line 194 "albumtheme.y"
+#line 194 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = NULL;
 		;}
@@ -1701,7 +1701,7 @@ yyreduce:
   case 22:
 
 /* Line 1455 of yacc.c  */
-#line 205 "albumtheme.y"
+#line 205 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.tag) = gth_tag_new (GTH_TAG_SET_VAR, (yyvsp[(2) - (3)].list));
 		;}
@@ -1710,30 +1710,30 @@ yyreduce:
   case 23:
 
 /* Line 1455 of yacc.c  */
-#line 210 "albumtheme.y"
+#line 210 "../../../extensions/webalbums/albumtheme.y"
     {
 			if (gth_tag_get_type_from_name ((yyvsp[(2) - (4)].text)) == GTH_TAG_EVAL) {
 				GthExpr *e;
 				GList   *arg_list;
-				
+
 				if ((yyvsp[(3) - (4)].list) == NULL) {
 					yyerror ("Missing argument for function 'eval', expected expression");
 					YYERROR;
 				}
-				
+
 				e = (yyvsp[(3) - (4)].list)->data;
 				arg_list = g_list_append (NULL, gth_attribute_new_expression ("expr", e));
 				(yyval.tag) = gth_tag_new (GTH_TAG_EVAL, arg_list);
-				
+
 				gth_expr_list_unref ((yyvsp[(3) - (4)].list));
 			}
 			else if (gth_tag_get_type_from_name ((yyvsp[(2) - (4)].text)) == GTH_TAG_TRANSLATE) {
 				GList *arg_list = NULL;
 				GList *scan;
-				
+
 				for (scan = (yyvsp[(3) - (4)].list); scan; scan = scan->next) {
 					GthExpr *e = scan->data;
-					
+
 					if (scan == (yyvsp[(3) - (4)].list)) {
 						GthCell *cell;
 
@@ -1741,16 +1741,16 @@ yyreduce:
 						if (cell->type != GTH_CELL_TYPE_STRING) {
 							yyerror ("Wrong argument type: %d, expected string", cell->type);
 							YYERROR;
-						}						
+						}
 						arg_list = g_list_append (arg_list, gth_attribute_new_string ("text", cell->value.string->str));
 
 						continue;
 					}
-									
+
 					arg_list = g_list_append (arg_list, gth_attribute_new_expression ("expr", e));
 				}
 				(yyval.tag) = gth_tag_new (GTH_TAG_TRANSLATE, arg_list);
-				
+
 				gth_expr_list_unref ((yyvsp[(3) - (4)].list));
 			}
 			else {
@@ -1763,7 +1763,7 @@ yyreduce:
   case 24:
 
 /* Line 1455 of yacc.c  */
-#line 258 "albumtheme.y"
+#line 258 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthTagType tag_type = gth_tag_get_type_from_name ((yyvsp[(2) - (4)].text));
 			if (tag_type == GTH_TAG_INVALID) {
@@ -1777,7 +1777,7 @@ yyreduce:
   case 25:
 
 /* Line 1455 of yacc.c  */
-#line 268 "albumtheme.y"
+#line 268 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].attribute));
 		;}
@@ -1786,7 +1786,7 @@ yyreduce:
   case 26:
 
 /* Line 1455 of yacc.c  */
-#line 272 "albumtheme.y"
+#line 272 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		;}
@@ -1795,7 +1795,7 @@ yyreduce:
   case 27:
 
 /* Line 1455 of yacc.c  */
-#line 277 "albumtheme.y"
+#line 277 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.attribute) = gth_attribute_new_expression ((yyvsp[(1) - (5)].text), (yyvsp[(4) - (5)].expr));
 			g_free ((yyvsp[(1) - (5)].text));
@@ -1805,7 +1805,7 @@ yyreduce:
   case 28:
 
 /* Line 1455 of yacc.c  */
-#line 282 "albumtheme.y"
+#line 282 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.attribute) = gth_attribute_new_string ((yyvsp[(1) - (5)].text), (yyvsp[(4) - (5)].text));
 			g_free ((yyvsp[(1) - (5)].text));
@@ -1816,7 +1816,7 @@ yyreduce:
   case 29:
 
 /* Line 1455 of yacc.c  */
-#line 288 "albumtheme.y"
+#line 288 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_integer (e, 1);
@@ -1828,7 +1828,7 @@ yyreduce:
   case 30:
 
 /* Line 1455 of yacc.c  */
-#line 296 "albumtheme.y"
+#line 296 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].expr));
 		;}
@@ -1837,7 +1837,7 @@ yyreduce:
   case 31:
 
 /* Line 1455 of yacc.c  */
-#line 300 "albumtheme.y"
+#line 300 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend (NULL, (yyvsp[(1) - (1)].expr));
 		;}
@@ -1846,7 +1846,7 @@ yyreduce:
   case 32:
 
 /* Line 1455 of yacc.c  */
-#line 304 "albumtheme.y"
+#line 304 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		;}
@@ -1855,7 +1855,7 @@ yyreduce:
   case 33:
 
 /* Line 1455 of yacc.c  */
-#line 309 "albumtheme.y"
+#line 309 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.expr) = (yyvsp[(2) - (3)].expr);
 		;}
@@ -1864,7 +1864,7 @@ yyreduce:
   case 34:
 
 /* Line 1455 of yacc.c  */
-#line 313 "albumtheme.y"
+#line 313 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1882,7 +1882,7 @@ yyreduce:
   case 35:
 
 /* Line 1455 of yacc.c  */
-#line 326 "albumtheme.y"
+#line 326 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1900,7 +1900,7 @@ yyreduce:
   case 36:
 
 /* Line 1455 of yacc.c  */
-#line 339 "albumtheme.y"
+#line 339 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1918,7 +1918,7 @@ yyreduce:
   case 37:
 
 /* Line 1455 of yacc.c  */
-#line 352 "albumtheme.y"
+#line 352 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1936,7 +1936,7 @@ yyreduce:
   case 38:
 
 /* Line 1455 of yacc.c  */
-#line 365 "albumtheme.y"
+#line 365 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1954,7 +1954,7 @@ yyreduce:
   case 39:
 
 /* Line 1455 of yacc.c  */
-#line 378 "albumtheme.y"
+#line 378 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1972,7 +1972,7 @@ yyreduce:
   case 40:
 
 /* Line 1455 of yacc.c  */
-#line 391 "albumtheme.y"
+#line 391 "../../../extensions/webalbums/albumtheme.y"
     {
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
 		;}
@@ -1981,7 +1981,7 @@ yyreduce:
   case 41:
 
 /* Line 1455 of yacc.c  */
-#line 395 "albumtheme.y"
+#line 395 "../../../extensions/webalbums/albumtheme.y"
     {
 			gth_expr_push_op ((yyvsp[(2) - (2)].expr), GTH_OP_NEG);
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
@@ -1991,7 +1991,7 @@ yyreduce:
   case 42:
 
 /* Line 1455 of yacc.c  */
-#line 400 "albumtheme.y"
+#line 400 "../../../extensions/webalbums/albumtheme.y"
     {
 			gth_expr_push_op ((yyvsp[(2) - (2)].expr), GTH_OP_NOT);
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
@@ -2001,18 +2001,18 @@ yyreduce:
   case 43:
 
 /* Line 1455 of yacc.c  */
-#line 405 "albumtheme.y"
+#line 405 "../../../extensions/webalbums/albumtheme.y"
     { /* function call */
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_var (e, (yyvsp[(1) - (4)].text));
 			if ((yyvsp[(3) - (4)].list) != NULL) {
 				GList *scan;
-				
+
 				for (scan = (yyvsp[(3) - (4)].list); scan; scan = scan->next) {
-					GthExpr *arg = scan->data;					
+					GthExpr *arg = scan->data;
 					gth_expr_push_expr (e, arg);
 					gth_expr_unref (arg);
-				}				
+				}
 				g_list_free ((yyvsp[(3) - (4)].list));
 			}
 			g_free ((yyvsp[(1) - (4)].text));
@@ -2023,7 +2023,7 @@ yyreduce:
   case 44:
 
 /* Line 1455 of yacc.c  */
-#line 422 "albumtheme.y"
+#line 422 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_var (e, (yyvsp[(1) - (1)].text));
@@ -2035,7 +2035,7 @@ yyreduce:
   case 45:
 
 /* Line 1455 of yacc.c  */
-#line 429 "albumtheme.y"
+#line 429 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_string (e, (yyvsp[(2) - (3)].text));
@@ -2047,7 +2047,7 @@ yyreduce:
   case 46:
 
 /* Line 1455 of yacc.c  */
-#line 436 "albumtheme.y"
+#line 436 "../../../extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_integer (e, (yyvsp[(1) - (1)].ivalue));
@@ -2270,7 +2270,7 @@ yyreturn:
 
 
 /* Line 1675 of yacc.c  */
-#line 443 "albumtheme.y"
+#line 443 "../../../extensions/webalbums/albumtheme.y"
 
 
 
