@@ -23,6 +23,7 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include "gconf-utils.h"
 #include "glib-utils.h"
 #include "gth-cell-renderer-thumbnail.h"
 #include "gth-dumb-notebook.h"
@@ -31,11 +32,11 @@
 #include "gth-file-store.h"
 #include "gth-icon-cache.h"
 #include "gth-icon-view.h"
+#include "gth-preferences.h"
 #include "gth-thumb-loader.h"
 #include "gtk-utils.h"
 
 
-#define DEFAULT_THUMBNAIL_SIZE 112
 #define FLASH_THUMBNAIL_QUEUE_TIMEOUT 75
 #define UPDATE_THUMBNAILS_AFTER_SCROLL_TIMEOUT 125
 #define RESTART_LOADING_THUMBS_DELAY 1500
@@ -87,6 +88,17 @@ typedef struct {
 } ThumbData;
 
 
+typedef struct {
+	GthFileList    *file_list;
+	GthThumbLoader *loader;
+	GCancellable   *cancellable;
+	GthFileData    *file_data;
+	gboolean        update_in_view;
+	int             pos;
+	gboolean        started;
+} ThumbnailJob;
+
+
 enum {
 	FILE_POPUP,
 	LAST_SIGNAL
@@ -123,7 +135,10 @@ struct _GthFileListPrivateData
 	GtkCellRenderer *text_renderer;
 	GtkCellRenderer *checkbox_renderer;
 	char           **caption_attributes_v;
-	gboolean         cancelled;
+	gboolean         cancelling;
+	guint            update_event;
+	gboolean         visibility_changed;
+	GList           *visibles;
 };
 
 
@@ -181,6 +196,12 @@ _gth_file_list_clear_queue (GthFileList *file_list)
 {
 	if (file_list->priv->dirty_event != 0) {
 		g_source_remove (file_list->priv->dirty_event);
+		file_list->priv->dirty_event = 0;
+		file_list->priv->dirty = FALSE;
+	}
+
+	if (file_list->priv->update_event != 0) {
+		g_source_remove (file_list->priv->update_event);
 		file_list->priv->dirty = FALSE;
 	}
 
@@ -228,7 +249,7 @@ _gth_file_list_queue_op (GthFileList   *file_list,
 	if (op->type == GTH_FILE_LIST_OP_TYPE_SET_FILTER)
 		_gth_file_list_remove_op (file_list, GTH_FILE_LIST_OP_TYPE_SET_FILTER);
 	file_list->priv->queue = g_list_append (file_list->priv->queue, op);
-	file_list->priv->cancelled = FALSE;
+
 	if (! file_list->priv->loading_thumbs)
 		_gth_file_list_exec_next_op (file_list);
 }
@@ -248,6 +269,8 @@ gth_file_list_finalize (GObject *object)
 	file_list = GTH_FILE_LIST (object);
 
 	if (file_list->priv != NULL) {
+		_g_object_unref (file_list->priv->thumb_loader);
+		_g_object_list_unref (file_list->priv->visibles);
 		g_hash_table_unref (file_list->priv->thumb_data);
 		if (file_list->priv->icon_cache != NULL)
 			gth_icon_cache_free (file_list->priv->icon_cache);
@@ -315,6 +338,9 @@ gth_file_list_class_init (GthFileListClass *class)
 }
 
 
+/* -- ThumbData -- */
+
+
 static ThumbData *
 thumb_data_new (void)
 {
@@ -346,6 +372,9 @@ thumb_data_unref (ThumbData *data)
 }
 
 
+/* --- */
+
+
 static void
 gth_file_list_init (GthFileList *file_list)
 {
@@ -355,7 +384,10 @@ gth_file_list_init (GthFileList *file_list)
 	file_list->priv->ignore_hidden_thumbs = FALSE;
 	file_list->priv->load_thumbs = TRUE;
 	file_list->priv->caption_attributes_v = g_strsplit ("none", ",", -1);
-	file_list->priv->cancelled = FALSE;
+	file_list->priv->cancelling = FALSE;
+	file_list->priv->update_event = 0;
+	file_list->priv->visibles = NULL;
+	file_list->priv->visibility_changed = FALSE;
 }
 
 
@@ -382,7 +414,7 @@ restart_thumb_update_cb (gpointer data)
 static void
 start_update_next_thumb (GthFileList *file_list)
 {
-	if (file_list->priv->cancelled)
+	if (file_list->priv->cancelling)
 		return;
 
 	if (file_list->priv->loading_thumbs)
@@ -399,6 +431,44 @@ start_update_next_thumb (GthFileList *file_list)
 }
 
 
+static void
+_gth_file_list_done (GthFileList *file_list)
+{
+	file_list->priv->loading_thumbs = FALSE;
+}
+
+
+/* ThumbnailJob */
+
+
+static void
+thumbnail_job_free (ThumbnailJob *job)
+{
+	job->file_list->priv->jobs = g_list_remove (job->file_list->priv->jobs, job);
+	if (job->file_list->priv->jobs == NULL)
+		_gth_file_list_done (job->file_list);
+
+	_g_object_unref (job->file_data);
+	_g_object_unref (job->cancellable);
+	_g_object_unref (job->loader);
+	_g_object_unref (job->file_list);
+	g_free (job);
+}
+
+
+static void
+thumbnail_job_cancel (ThumbnailJob *job)
+{
+	if (job->started)
+		g_cancellable_cancel (job->cancellable);
+	else
+		thumbnail_job_free (job);
+}
+
+
+/* --- */
+
+
 static void
 vadj_changed_cb (GtkAdjustment *adjustment,
 		 gpointer       user_data)
@@ -499,14 +569,37 @@ _gth_file_list_set_type (GthFileList     *file_list,
 		      "visible", ((file_list->priv->type == GTH_FILE_LIST_TYPE_BROWSER) || (file_list->priv->type == GTH_FILE_LIST_TYPE_SELECTOR)),
 		      NULL);
 
+	/* use the fixed size for horizontal sidebars to view a single row at
+	 * a time. */
+
 	g_object_set (file_list->priv->thumbnail_renderer,
-		      "fixed_size", (file_list->priv->type == GTH_FILE_LIST_TYPE_H_SIDEBAR) || (file_list->priv->type == GTH_FILE_LIST_TYPE_V_SIDEBAR),
+		      "fixed_size", (file_list->priv->type == GTH_FILE_LIST_TYPE_H_SIDEBAR),
 		      NULL);
 
 	_gth_file_list_update_orientation (file_list);
 }
 
 
+static void
+file_store_visibility_changed_cb (GthFileStore *file_store,
+				  GthFileList  *file_list)
+{
+	file_list->priv->visibility_changed = TRUE;
+}
+
+
+static void
+file_store_rows_reordered_cb (GtkTreeModel *tree_model,
+			      GtkTreePath  *path,
+			      GtkTreeIter  *iter,
+			      gpointer      new_order,
+			      gpointer      user_data)
+{
+	GthFileList *file_list = user_data;
+	file_list->priv->visibility_changed = TRUE;
+}
+
+
 static void
 gth_file_list_construct (GthFileList     *file_list,
 			 GthFileListType  list_type,
@@ -554,6 +647,15 @@ gth_file_list_construct (GthFileList     *file_list,
 	file_list->priv->view = gth_icon_view_new_with_model (GTK_TREE_MODEL (model));
 	g_object_unref (model);
 
+	g_signal_connect (model,
+			  "visibility-changed",
+			  G_CALLBACK (file_store_visibility_changed_cb),
+			  file_list);
+	g_signal_connect (model,
+			  "rows-reordered",
+			  G_CALLBACK (file_store_rows_reordered_cb),
+			  file_list);
+
 	if (enable_drag_drop) {
 		GtkTargetList  *target_list;
 		GtkTargetEntry *targets;
@@ -707,46 +809,6 @@ gth_file_list_set_type (GthFileList     *file_list,
 }
 
 
-static void
-_gth_file_list_done (GthFileList *file_list)
-{
-	file_list->priv->loading_thumbs = FALSE;
-}
-
-
-typedef struct {
-	GthFileList    *file_list;
-	GthThumbLoader *loader;
-	GCancellable   *cancellable;
-	GthFileData    *file_data;
-	gboolean        update_in_view;
-	int             pos;
-} ThumbnailJob;
-
-
-static void
-thumbnail_job_free (ThumbnailJob *job)
-{
-	job->file_list->priv->jobs = g_list_remove (job->file_list->priv->jobs, job);
-	if (job->file_list->priv->jobs == NULL)
-		_gth_file_list_done (job->file_list);
-
-	_g_object_unref (job->file_data);
-	_g_object_unref (job->cancellable);
-	_g_object_unref (job->loader);
-	_g_object_unref (job->file_list);
-	g_free (job);
-}
-
-
-static void
-thumbnail_job_cancel (ThumbnailJob *job)
-{
-	if (! g_cancellable_is_cancelled (job->cancellable))
-		g_cancellable_cancel (job->cancellable);
-}
-
-
 typedef struct {
 	GthFileList *file_list;
 	DataFunc     done_func;
@@ -775,6 +837,7 @@ wait_for_jobs_to_finish (gpointer user_data)
 			g_source_remove (cancel_data->check_id);
 			cancel_data->check_id = 0;
 		}
+		cancel_data->file_list->priv->cancelling = FALSE;
 		if (cancel_data->done_func != NULL)
 			cancel_data->done_func (cancel_data->user_data);
 		cancel_data_free (cancel_data);
@@ -791,6 +854,7 @@ _gth_file_list_cancel_jobs (GthFileList *file_list,
 			    gpointer     user_data)
 {
 	CancelData *cancel_data;
+	GList      *list;
 	GList      *scan;
 
 	cancel_data = g_new0 (CancelData, 1);
@@ -803,10 +867,12 @@ _gth_file_list_cancel_jobs (GthFileList *file_list,
 		return;
 	}
 
-	for (scan = file_list->priv->jobs; scan; scan = scan->next) {
+	list = g_list_copy (file_list->priv->jobs);
+	for (scan = list; scan; scan = scan->next) {
 		ThumbnailJob *job = scan->data;
 		thumbnail_job_cancel (job);
 	}
+	g_list_free (list);
 
 	cancel_data->check_id = g_timeout_add (CHECK_JOBS_INTERVAL,
 					       wait_for_jobs_to_finish,
@@ -819,7 +885,7 @@ gth_file_list_cancel (GthFileList    *file_list,
 		      DataFunc        done_func,
 		      gpointer        user_data)
 {
-	file_list->priv->cancelled = TRUE;
+	file_list->priv->cancelling = TRUE;
 	_gth_file_list_clear_queue (file_list);
 	_gth_file_list_cancel_jobs (file_list, done_func, user_data);
 }
@@ -1100,6 +1166,8 @@ static void
 gfl_set_files (GthFileList *file_list,
 	       GList       *files)
 {
+	gth_thumb_loader_set_save_thumbnails (file_list->priv->thumb_loader, eel_gconf_get_boolean (PREF_SAVE_THUMBNAILS, TRUE));
+	gth_thumb_loader_set_max_file_size (file_list->priv->thumb_loader, eel_gconf_get_integer (PREF_THUMBNAIL_LIMIT, 0));
 	gth_file_selection_unselect_all (GTH_FILE_SELECTION (file_list->priv->view));
 
 	gth_file_store_clear ((GthFileStore*) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view)));
@@ -1214,6 +1282,9 @@ gfl_enable_thumbs (GthFileList *file_list,
 	GthFileStore *file_store;
 	GtkTreeIter   iter;
 
+	gth_thumb_loader_set_save_thumbnails (file_list->priv->thumb_loader, eel_gconf_get_boolean (PREF_SAVE_THUMBNAILS, TRUE));
+	gth_thumb_loader_set_max_file_size (file_list->priv->thumb_loader, eel_gconf_get_integer (PREF_THUMBNAIL_LIMIT, 0));
+
 	file_list->priv->load_thumbs = enable;
 
 	file_store = (GthFileStore*) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view));
@@ -1274,7 +1345,10 @@ gth_file_list_set_thumb_size (GthFileList *file_list,
 			      int          size)
 {
 	file_list->priv->thumb_size = size;
+
 	gth_thumb_loader_set_requested_size (file_list->priv->thumb_loader, size);
+	gth_thumb_loader_set_save_thumbnails (file_list->priv->thumb_loader, eel_gconf_get_boolean (PREF_SAVE_THUMBNAILS, TRUE));
+	gth_thumb_loader_set_max_file_size (file_list->priv->thumb_loader, eel_gconf_get_integer (PREF_THUMBNAIL_LIMIT, 0));
 
 	gth_icon_cache_free (file_list->priv->icon_cache);
 	file_list->priv->icon_cache = gth_icon_cache_new (gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (file_list))), size / 2);
@@ -1482,8 +1556,11 @@ thumbnail_job_ready_cb (GObject      *source_object,
 						result,
 						&pixbuf,
 						&error);
+	job->started = FALSE;
 
-	if (! success && g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+	if ((! success && g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+	    || file_list->priv->cancelling)
+	{
 		thumbnail_job_free (job);
 		return;
 	}
@@ -1557,6 +1634,7 @@ start_thumbnail_job (gpointer user_data)
 {
 	ThumbnailJob *job = user_data;
 
+	job->started = TRUE;
 	gth_thumb_loader_load (job->loader,
 			       job->file_data,
 			       job->cancellable,
@@ -1571,8 +1649,14 @@ static void
 _gth_file_list_update_thumb (GthFileList  *file_list,
 			     ThumbnailJob *job)
 {
+	GList *list;
 	GList *scan;
 
+	if (file_list->priv->update_event != 0) {
+		g_source_remove (file_list->priv->update_event);
+		file_list->priv->update_event = 0;
+	}
+
 	if (! job->update_in_view) {
 		ThumbData *thumb_data;
 
@@ -1592,20 +1676,23 @@ _gth_file_list_update_thumb (GthFileList  *file_list,
 		}
 
 		if (job == NULL) {
-			g_idle_add (restart_thumb_update_cb, file_list);
+			file_list->priv->update_event = g_idle_add (restart_thumb_update_cb, file_list);
 			return;
 		}
 	}
 
-	for (scan = file_list->priv->jobs; scan; scan = scan->next) {
+	list = g_list_copy (file_list->priv->jobs);
+	for (scan = list; scan; scan = scan->next) {
 		ThumbnailJob *other_job = scan->data;
 		thumbnail_job_cancel (other_job);
 	}
+	g_list_free (list);
+
 	file_list->priv->jobs = g_list_prepend (file_list->priv->jobs, job);
 
 	if (job->update_in_view)
 		set_loading_icon (job->file_list, job->file_data, job->pos);
-	g_idle_add (start_thumbnail_job, job);
+	file_list->priv->update_event = g_idle_add (start_thumbnail_job, job);
 }
 
 
@@ -1650,6 +1737,19 @@ can_create_file_thumbnail (GthFileData *file_data,
 }
 
 
+static GList *
+_gth_file_list_get_visibles (GthFileList *file_list)
+{
+	if (file_list->priv->visibility_changed) {
+		_g_object_list_unref (file_list->priv->visibles);
+		file_list->priv->visibles = gth_file_store_get_visibles ((GthFileStore *) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view)));
+		file_list->priv->visibility_changed = FALSE;
+	}
+
+	return file_list->priv->visibles;
+}
+
+
 static void
 _gth_file_list_update_next_thumb (GthFileList *file_list)
 {
@@ -1666,15 +1766,20 @@ _gth_file_list_update_next_thumb (GthFileList *file_list)
 	ThumbnailJob  *job;
 
 	if (file_list->priv->queue != NULL) {
-		g_idle_add (update_thumbs_stopped, file_list);
+		if (file_list->priv->update_event != 0)
+			g_source_remove (file_list->priv->update_event);
+		file_list->priv->update_event = g_idle_add (update_thumbs_stopped, file_list);
 		return;
 	}
 
+	if (file_list->priv->cancelling)
+		return;
+
 	file_store = (GthFileStore *) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view));
 
 	/* Find first visible undone. */
 
-	list = gth_file_store_get_visibles (file_store);
+	list = _gth_file_list_get_visibles (file_list);
 	first_pos = gth_file_view_get_first_visible (GTH_FILE_VIEW (file_list->priv->view));
 	last_pos = gth_file_view_get_last_visible (GTH_FILE_VIEW (file_list->priv->view));
 
@@ -1683,7 +1788,6 @@ _gth_file_list_update_next_thumb (GthFileList *file_list)
 	if (pos >= 0)
 		scan = g_list_nth (list, pos);
 	if (scan == NULL) {
-		_g_object_list_unref (list);
 		_gth_file_list_thumbs_completed (file_list);
 		return;
 	}
@@ -1761,8 +1865,6 @@ _gth_file_list_update_next_thumb (GthFileList *file_list)
 	if (new_pos != -1)
 		file_data = g_object_ref (file_data);
 
-	_g_object_list_unref (list);
-
 	if (new_pos == -1) {
 		_gth_file_list_thumbs_completed (file_list);
 		if (young_file_found && (file_list->priv->restart_thumb_update == 0))
@@ -1772,7 +1874,7 @@ _gth_file_list_update_next_thumb (GthFileList *file_list)
 
 	job = g_new0 (ThumbnailJob, 1);
 	job->file_list = g_object_ref (file_list);
-	job->loader = gth_thumb_loader_new (file_list->priv->thumb_size);
+	job->loader = g_object_ref (file_list->priv->thumb_loader);
 	job->cancellable = g_cancellable_new ();
 	job->file_data = file_data; /* already ref-ed above */
 	job->pos = new_pos;
@@ -1858,13 +1960,11 @@ gth_file_list_first_file (GthFileList *file_list,
 			  gboolean     skip_broken,
 			  gboolean     only_selected)
 {
-	GthFileView *view;
-	GList       *files;
-	GList       *scan;
-	int          pos;
+	GList *files;
+	GList *scan;
+	int    pos;
 
-	view = GTH_FILE_VIEW (file_list->priv->view);
-	files = gth_file_store_get_visibles (GTH_FILE_STORE (gth_file_view_get_model (view)));
+	files = _gth_file_list_get_visibles (file_list);
 
 	pos = 0;
 	for (scan = files; scan; scan = scan->next, pos++) {
@@ -1874,7 +1974,7 @@ gth_file_list_first_file (GthFileList *file_list,
 		thumb_data = g_hash_table_lookup (file_list->priv->thumb_data, file_data->file);
 		if (skip_broken && thumb_data->error)
 			continue;
-		if (only_selected && ! gth_file_selection_is_selected (GTH_FILE_SELECTION (view), pos))
+		if (only_selected && ! gth_file_selection_is_selected (GTH_FILE_SELECTION (file_list->priv->view), pos))
 			continue;
 
 		return pos;
@@ -1889,13 +1989,11 @@ gth_file_list_last_file (GthFileList *file_list,
 			 gboolean     skip_broken,
 			 gboolean     only_selected)
 {
-	GthFileView *view;
-	GList       *files;
-	GList       *scan;
-	int          pos;
+	GList *files;
+	GList *scan;
+	int    pos;
 
-	view = GTH_FILE_VIEW (file_list->priv->view);
-	files = gth_file_store_get_visibles (GTH_FILE_STORE (gth_file_view_get_model (view)));
+	files = _gth_file_list_get_visibles (file_list);
 
 	pos = g_list_length (files) - 1;
 	if (pos < 0)
@@ -1908,7 +2006,7 @@ gth_file_list_last_file (GthFileList *file_list,
 		thumb_data = g_hash_table_lookup (file_list->priv->thumb_data, file_data->file);
 		if (skip_broken && thumb_data->error)
 			continue;
-		if (only_selected && ! gth_file_selection_is_selected (GTH_FILE_SELECTION (view), pos))
+		if (only_selected && ! gth_file_selection_is_selected (GTH_FILE_SELECTION (file_list->priv->view), pos))
 			continue;
 
 		return pos;
@@ -1925,12 +2023,10 @@ gth_file_list_next_file (GthFileList *file_list,
 			 gboolean     only_selected,
 			 gboolean     wrap)
 {
-	GthFileView *view;
-	GList       *files;
-	GList       *scan;
+	GList *files;
+	GList *scan;
 
-	view = GTH_FILE_VIEW (file_list->priv->view);
-	files = gth_file_store_get_visibles (GTH_FILE_STORE (gth_file_view_get_model (view)));
+	files = _gth_file_list_get_visibles (file_list);
 
 	pos++;
 	if (pos >= 0)
@@ -1947,14 +2043,12 @@ gth_file_list_next_file (GthFileList *file_list,
 		thumb_data = g_hash_table_lookup (file_list->priv->thumb_data, file_data->file);
 		if (skip_broken && thumb_data->error)
 			continue;
-		if (only_selected && ! gth_file_selection_is_selected (GTH_FILE_SELECTION (view), pos))
+		if (only_selected && ! gth_file_selection_is_selected (GTH_FILE_SELECTION (file_list->priv->view), pos))
 			continue;
 
 		break;
 	}
 
-	_g_object_list_unref (files);
-
 	return (scan != NULL) ? pos : -1;
 }
 
@@ -1966,12 +2060,10 @@ gth_file_list_prev_file (GthFileList *file_list,
 			 gboolean     only_selected,
 			 gboolean     wrap)
 {
-	GthFileView *view;
-	GList       *files;
-	GList       *scan;
+	GList *files;
+	GList *scan;
 
-	view = GTH_FILE_VIEW (file_list->priv->view);
-	files = gth_file_store_get_visibles (GTH_FILE_STORE (gth_file_view_get_model (view)));
+	files = _gth_file_list_get_visibles (file_list);
 
 	pos--;
 	if (pos >= 0)
@@ -1990,14 +2082,12 @@ gth_file_list_prev_file (GthFileList *file_list,
 		thumb_data = g_hash_table_lookup (file_list->priv->thumb_data, file_data->file);
 		if (skip_broken && thumb_data->error)
 			continue;
-		if (only_selected && ! gth_file_selection_is_selected (GTH_FILE_SELECTION (view), pos))
+		if (only_selected && ! gth_file_selection_is_selected (GTH_FILE_SELECTION (file_list->priv->view), pos))
 			continue;
 
 		break;
 	}
 
-	_g_object_list_unref (files);
-
 	return (scan != NULL) ? pos : -1;
 }
 
